Convert Data to List
dat2list.RdThis function reads data from a file and converts it into a list. If the data are numeric, it maintains the numeric list. If the data are strings, it returns a character string.
dat2list.RdThis function reads data from a file and converts it into a list. If the data are numeric, it maintains the numeric list. If the data are strings, it returns a character string.